**Attitude** is a Python module for fitting the orientation of planes! Its core mission is to compute
planar fits and transform them (*along with meaningful error distributions*) into
a form that can be used for geology. It is designed to support the collection of structural
measurements from remote sensing data.

The documentation for the module can be found at
https://davenquinn.github.io/Attitude, and a preprint publication
describing the underlying statistical method is on
[EarthArXiV](https://eartharxiv.org/4enzu/).
